==> surefire_2.19.1.orig.tar.xz: surefire-2.19.1/surefire-integration-tests/src/test/java/org/apache/maven/surefire/its/jiras/Surefire817SystemExitIT.java <==
package org.apache.maven.surefire.its.jiras;

/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

import org.apache.maven.it.VerificationException;
import org.apache.maven.surefire.its.fixture.SurefireJUnit4IntegrationTestCase;
import org.apache.maven.surefire.its.fixture.SurefireLauncher;
import org.junit.Test;

/**
 * @author <a href="mailto:tibordigana@apache.org">Tibor Digana (tibor17)</a>
 * @see {@linkplain https://jira.codehaus.org/browse/SUREFIRE-817}
 * @since 2.18
 */
public class Surefire817SystemExitIT
    extends SurefireJUnit4IntegrationTestCase
{

    @Test
    public void systemExit1()
        throws VerificationException
    {
        unpack().maven().withFailure().executeTest().verifyTextInLog( "class jiras.surefire817.Test main" );
    }

    private SurefireLauncher unpack()
    {
        return unpack( "surefire-817-system-exit" );
    }
}

==> surefire_2.20.1.orig.tar.xz: surefire-2.20.1/surefire-integration-tests/src/test/java/org/apache/maven/surefire/its/jiras/Surefire817SystemExitIT.java <==
package org.apache.maven.surefire.its.jiras;

/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

import org.apache.maven.it.VerificationException;
import org.apache.maven.surefire.its.fixture.SurefireJUnit4IntegrationTestCase;
import org.apache.maven.surefire.its.fixture.SurefireLauncher;
import org.junit.Test;

/**
 * @author <a href="mailto:tibordigana@apache.org">Tibor Digana (tibor17)</a>
 * @see <a href="https://issues.apache.org/jira/browse/SUREFIRE-817">SUREFIRE-817</a>
 * @since 2.18
 */
public class Surefire817SystemExitIT
    extends SurefireJUnit4IntegrationTestCase
{

    @Test
    public void systemExit1()
        throws VerificationException
    {
        unpack().maven().withFailure().executeTest().verifyTextInLog( "class jiras.surefire817.Test main" );
    }

    private SurefireLauncher unpack()
    {
        return unpack( "surefire-817-system-exit" );
    }
}
